ChannelVideo class abstract
Metadata related to content from a channel's page (video)
- Annotations
-
- @freezed
Constructors
Properties
-
copyWith
→ $ChannelVideoCopyWith<
ChannelVideo> -
Create a copy of ChannelVideo
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- videoDuration → Duration
-
Video duration, this is always zero for shorts.
no setterinherited
- videoId → VideoId
-
Video ID.
no setterinherited
- videoThumbnail → String
-
Video thumbnail
no setterinherited
- videoTitle → String
-
Video title.
no setterinherited
- videoUploadDate → String
-
Video upload date. This is always empty for shorts.
Formatted like 10 hours ago
no setterinherited
- videoViews → int
-
Video view count.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited